[tor-commits] [flashproxy/master] Make the badge XCF nicer.

dcf at torproject.org dcf at torproject.org
Thu May 7 16:18:43 UTC 2015


commit ba0a517d25bd94bfba5424a4b3309801e5dfd5ff
Author: David Fifield <david at bamsoftware.com>
Date:   Thu May 7 09:03:34 2015 -0700

    Make the badge XCF nicer.
    
    Threshold-alpha the text layers (some pixels were semi-transparent).
    Move the border to its own layer.
---
 proxy/badge-export-lang.scm |    4 +++-
 proxy/badge.xcf             |  Bin 3690 -> 3657 bytes
 2 files changed, 3 insertions(+), 1 deletion(-)

diff --git a/proxy/badge-export-lang.scm b/proxy/badge-export-lang.scm
index 51f78f1..1e91967 100644
--- a/proxy/badge-export-lang.scm
+++ b/proxy/badge-export-lang.scm
@@ -6,13 +6,15 @@
 (define (export lang)
   (let* ((image (car (gimp-file-load RUN-NONINTERACTIVE xcf-filename xcf-filename)))
          (shine-layer (car (gimp-image-get-layer-by-name image "shine")))
+         (border-layer (car (gimp-image-get-layer-by-name image "border")))
          (text-layer (car (gimp-image-get-layer-by-name image (string-append "text-" lang))))
          (output-filename (string-append "badge-" lang ".png")))
     ; Turn off all layers.
     (for-each (lambda (x) (gimp-item-set-visible x FALSE))
               (vector->list (cadr (gimp-image-get-layers image))))
     ; Except the shine and the wanted text.
     (gimp-item-set-visible shine-layer TRUE)
+    (gimp-item-set-visible border-layer TRUE)
     (gimp-item-set-visible text-layer TRUE)
     (gimp-image-merge-visible-layers image CLIP-TO-IMAGE)
     (file-png-save RUN-NONINTERACTIVE image
@@ -6,13 +6,15 @@
     (for-each (lambda (x) (gimp-item-set-visible x FALSE))
               (vector->list (cadr (gimp-image-get-layers image))))
-    ; Except the shine and the wanted text.
+    ; Except the shine, border, and the wanted text.
     (gimp-item-set-visible shine-layer TRUE)
diff --git a/proxy/badge.xcf b/proxy/badge.xcf
index cc3af06..c3482ed 100644
Binary files a/proxy/badge.xcf and b/proxy/badge.xcf differ





More information about the tor-commits mailing list